IapLogLevel enum

Log level for EasyIap.

Inheritance
Available extensions

Values

none → const IapLogLevel

No logging.

error → const IapLogLevel

Errors only.

warning → const IapLogLevel

Errors and warnings.

info → const IapLogLevel

Errors, warnings, and info.

debug → const IapLogLevel

All logs including debug.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IapLogLevel>
A constant List of the values in this enum, in order of their declaration.