SubscriptionStatus enum

Subscription status for display.

Inheritance
Available extensions

Values

active → const SubscriptionStatus

Subscription is active and not expiring soon.

expiringSoon → const SubscriptionStatus

Subscription is active but expiring soon.

expired → const SubscriptionStatus

Subscription has expired.

gracePeriod → const SubscriptionStatus

Subscription is in grace period (expired but still accessible).

none → const SubscriptionStatus

No subscription.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SubscriptionStatus>
A constant List of the values in this enum, in order of their declaration.