IapBuilder class

Builds UI based on product ownership state.

Automatically updates when ownership changes.

IapBuilder(
  iap: iap,
  productId: 'pro_monthly',
  owned: () => ProScreen(),
  notOwned: () => UpgradeScreen(),
  loading: () => LoadingScreen(),
)
Inheritance

Constructors

IapBuilder({Key? key, required EasyIap iap, required String productId, required Widget owned(), required Widget notOwned(), Widget loading()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
iap EasyIap
EasyIap instance.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading Widget Function()?
Builder for loading state (optional).
final
notOwned Widget Function()
Builder for when product is not owned.
final
owned Widget Function()
Builder for when product is owned.
final
productId String
Product ID to check ownership for.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<IapBuilder>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited