IapLogger class
Logger for EasyIap.
Enable logging during development:
IapLogger.level = IapLogLevel.debug;
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- customLogger ↔ void Function(IapLogLevel level, String message, {Object? error})?
-
Custom log handler (optional).
getter/setter pair
- level ↔ IapLogLevel
-
Current log level.
getter/setter pair
Static Methods
-
debug(
String message, {String? tag, Map< String, dynamic> ? data}) → void - Log a debug message.
-
error(
String message, {String? tag, Object? error, Map< String, dynamic> ? data}) → void - Log an error message.
-
info(
String message, {String? tag, Map< String, dynamic> ? data}) → void - Log an info message.
-
warning(
String message, {String? tag, Map< String, dynamic> ? data}) → void - Log a warning message.